@@ -1,4 +1,4 @@
-/* $Id: SUPDrvInternal.h 87729 2013-08-05 10:00:02Z aeichner $ */
+/* $Id: SUPDrvInternal.h 91386 2013-12-17 20:39:56Z vgalitsy $ */
 /** @file
  * VirtualBox Support Driver - Internal header.
  */
@@ -684,6 +684,11 @@ int  VBOXCALL   supdrvOSLdrLoad(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage, c
 void VBOXCALL   supdrvOSLdrUnload(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage);
 
 
+#if defined(RT_OS_DARWIN)
+int VBOXCALL    supdrvDarwinResumeSuspendedKbds(void);
+#endif
+
+
 /*******************************************************************************
 *   Shared Functions                                                           *
 *******************************************************************************/
